"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/index.ts
var src_exports = {};
__export(src_exports, {
  Highlight: () => Highlight,
  withHighlightConfig: () => withHighlightConfig
});
module.exports = __toCommonJS(src_exports);

// src/util/withHighlight.ts
var import_node = require("@highlight-run/node");
var Highlight = (options = {}) => (origHandler) => {
  return async (req, res) => {
    const processHighlightHeaders = () => {
      if (req.headers && req.headers[import_node.HIGHLIGHT_REQUEST_HEADER]) {
        const [secureSessionId, requestId] = `${req.headers[import_node.HIGHLIGHT_REQUEST_HEADER]}`.split("/");
        if (secureSessionId && requestId) {
          if (!import_node.H.isInitialized()) {
            import_node.H.init(options);
          }
          ;
          global.__HIGHLIGHT__ = { secureSessionId, requestId };
          return { secureSessionId, requestId };
        }
      }
      return { secureSessionId: void 0, requestId: void 0 };
    };
    const start = new Date();
    try {
      return await origHandler(req, res);
    } catch (e) {
      const { secureSessionId, requestId } = processHighlightHeaders();
      if (secureSessionId && requestId) {
        import_node.H.consumeEvent(secureSessionId);
        if (e instanceof Error) {
          import_node.H.consumeError(e, secureSessionId, requestId);
        }
      }
      res.statusCode = 500;
      res.statusMessage = "Internal Server Error";
      throw e;
    } finally {
      const delta = (new Date().getTime() - start.getTime()) * 1e6;
      const { secureSessionId, requestId } = processHighlightHeaders();
      if (secureSessionId) {
        import_node.H.recordMetric(secureSessionId, "latency", delta, requestId);
      }
    }
  };
};

// src/util/highlightWebpackPlugin.ts
var import_sourcemap_uploader = require("@highlight-run/sourcemap-uploader");
var HighlightWebpackPlugin = class {
  constructor(apiKey, appVersion, path, basePath) {
    this.apiKey = apiKey;
    this.appVersion = appVersion;
    this.path = path;
    this.basePath = basePath;
  }
  apply(compiler) {
    compiler.hooks.afterEmit.tap("HighlightWebpackPlugin", () => {
      (0, import_sourcemap_uploader.uploadSourcemaps)({
        apiKey: this.apiKey,
        appVersion: this.appVersion,
        path: this.path,
        basePath: this.basePath
      });
    });
    return compiler;
  }
};

// src/util/withHighlightConfig.ts
var getDefaultOpts = (config, highlightOpts) => {
  const isProdBuild = process.env.NODE_ENV === "production";
  return {
    uploadSourceMaps: isProdBuild && ((highlightOpts == null ? void 0 : highlightOpts.uploadSourceMaps) ?? !config.productionBrowserSourceMaps ?? true),
    configureHighlightProxy: (highlightOpts == null ? void 0 : highlightOpts.configureHighlightProxy) ?? true,
    apiKey: (highlightOpts == null ? void 0 : highlightOpts.apiKey) ?? "",
    appVersion: (highlightOpts == null ? void 0 : highlightOpts.appVersion) ?? "",
    sourceMapsPath: (highlightOpts == null ? void 0 : highlightOpts.sourceMapsPath) ?? ".next/",
    sourceMapsBasePath: (highlightOpts == null ? void 0 : highlightOpts.sourceMapsBasePath) ?? "_next/"
  };
};
var withHighlightConfig = (config, highlightOpts) => {
  const defaultOpts = getDefaultOpts(config, highlightOpts);
  let newRewrites = config.rewrites;
  if (defaultOpts.uploadSourceMaps || defaultOpts.configureHighlightProxy) {
    newRewrites = async () => {
      let re;
      if (!config.rewrites) {
        re = new Array();
      } else {
        re = await config.rewrites();
      }
      const sourcemapRewrite = {
        source: "/:path*.map",
        destination: "/404"
      };
      const highlightRewrite = {
        source: "/highlight-events",
        destination: "https://pub.highlight.run"
      };
      if (Array.isArray(re)) {
        return {
          beforeFiles: defaultOpts.uploadSourceMaps ? [sourcemapRewrite] : [],
          afterFiles: defaultOpts.configureHighlightProxy ? re.concat(highlightRewrite) : [],
          fallback: []
        };
      } else {
        return {
          beforeFiles: defaultOpts.uploadSourceMaps ? re.beforeFiles.concat(sourcemapRewrite) : re.beforeFiles,
          afterFiles: defaultOpts.configureHighlightProxy ? re.afterFiles.concat(highlightRewrite) : re.afterFiles,
          fallback: re.fallback
        };
      }
    };
  }
  let newWebpack = config.webpack;
  if (defaultOpts.uploadSourceMaps) {
    newWebpack = (webpackConfig, opts) => {
      let originalConfig = webpackConfig;
      if (config.webpack) {
        originalConfig = config.webpack(webpackConfig, opts);
      }
      originalConfig.plugins.push(
        new HighlightWebpackPlugin(
          defaultOpts.apiKey,
          defaultOpts.appVersion,
          defaultOpts.sourceMapsPath,
          defaultOpts.sourceMapsBasePath
        )
      );
      return originalConfig;
    };
  }
  return {
    ...config,
    productionBrowserSourceMaps: defaultOpts.uploadSourceMaps || config.productionBrowserSourceMaps,
    rewrites: newRewrites,
    webpack: newWebpack
  };
};
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  Highlight,
  withHighlightConfig
});
